@@ -28,18 +28,19 @@ sys.modules['foo'] = foo
 
 
 # -- General configuration ----------------------------------------------------
-needs_sphinx = '1.0'
+needs_sphinx = '2.1'  # MyST-Parser requires Sphinx 2.1 or newer.
 extensions = [
-    'sphinx.ext.autodoc',
-    'sphinx.ext.extlinks',
-    'sphinx.ext.intersphinx',
-    'sphinx.ext.viewcode',
-    'sphinx.ext.autosummary',
-    'sphinxcontrib.napoleon'
+    #'sphinx.ext.autodoc',
+    #'sphinx.ext.extlinks',
+    #'sphinx.ext.intersphinx',
+    #'sphinx.ext.viewcode',
+    #'sphinx.ext.autosummary',
+    #'sphinxcontrib.napoleon',
+    'myst_parser'
 ]
 
 templates_path = ['_templates']
-source_suffix = '.rst'
+source_suffix = ['.rst', '.md']
 master_doc = 'index'
 
 project = 'dpkt'
